@@ -34,7 +34,6 @@ class App(Generic[AppConfig, GenWorker]):
         self.workers = {}
         self.services = {}
         self.dispatcher = IDispatcher()
-        self._create_logger()
 
     @inject
     async def _before_app_run(self, app_container: AppContainer = Provide["<container>"]):
@@ -78,12 +77,6 @@ class App(Generic[AppConfig, GenWorker]):
             container.wire(modules=[worker.__module__])
             worker.wire_worker(container)
 
-    def _create_logger(self) -> None:
-        logger_conf = self.config.get("logger")
-        if logger_conf:
-            logger_conf = LoggerSettings(**logger_conf)
-        setup_loggers(logger_conf)
-
     def perform(self) -> List[Future[Any]]:
         """
         Call performs from isolates and return all isolates Futures
