@@ -1,6 +1,5 @@
 import asyncio
 from pathlib import Path
-from typing import Generic
 
 import loguru
 from dependency_injector import providers, containers
@@ -13,15 +12,12 @@ from web_foundation.app.infrastructure.database.models import AbstractDbModel
 from web_foundation.app.resources.database import DatabaseResource, DbConfig
 from web_foundation.app.service import Service
 from web_foundation.kernel import GenericIMessage
-from web_foundation.workers.background.executor.worker import TaskExecutor
 from web_foundation.workers.io.http.chaining import chain
-from web_foundation.workers.io.http.dict_router import DictRouter
+from web_foundation.workers.io.http.routers.dict_router import DictRouter
 from web_foundation.workers.io.http.routes_dict import routes_dict
-from web_foundation.workers.io.http.yaml_router import YamlRouter
 from web_foundation.workers.io.rt_connection import RtConnection
 from web_foundation.workers.io.sse.connection import SseRtMessage
-from web_foundation.workers.io.worker import ServerConfig, create_io_workers, HttpServer, subscribe_worker_rt_callback
-from web_foundation.workers.worker import GenWorker
+from web_foundation.workers.io.worker import ServerConfig, create_io_workers, subscribe_worker_rt_callback
 
 
 class AppConf(BaseSettings):
